You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@arrow.apache.org by li...@apache.org on 2022/12/06 20:48:29 UTC

[arrow-adbc] branch main updated: ci: fix typo in wheel tags (#222)

This is an automated email from the ASF dual-hosted git repository.

lidavidm pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/arrow-adbc.git


The following commit(s) were added to refs/heads/main by this push:
     new 9dc4f25  ci: fix typo in wheel tags (#222)
9dc4f25 is described below

commit 9dc4f25df797d271b199bb2da6f15b85af9864d5
Author: David Li <li...@gmail.com>
AuthorDate: Tue Dec 6 15:48:24 2022 -0500

    ci: fix typo in wheel tags (#222)
---
 ci/scripts/python_wheel_unix_build.sh | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/ci/scripts/python_wheel_unix_build.sh b/ci/scripts/python_wheel_unix_build.sh
index e49960e..5a4d7cb 100755
--- a/ci/scripts/python_wheel_unix_build.sh
+++ b/ci/scripts/python_wheel_unix_build.sh
@@ -69,9 +69,9 @@ PLAT_NAME=$(python -c "import sysconfig; print(sysconfig.get_platform()\
     .replace('-universal2', '-${PYTHON_ARCH}'))")
 if [[ "${arch}" = "arm64v8" && "$(uname)" = "Darwin" ]]; then
    # Manually override the tag in this case - CI will naively generate
    # "macos_10_9_arm64" but this isn't a 'real' tag because the first
    # version of macOS supporting AArch64 was macOS 11 Big Sur
-   PLAT_NAME="macos_11_0_arm64"
+   PLAT_NAME="macosx_11_0_arm64"
 fi
 
 echo "=== Building C/C++ driver components ==="
@@ -69,9 +69,9 @@ PLAT_NAME=$(python -c "import sysconfig; print(sysconfig.get_platform()\
 if [[ "${arch}" = "arm64v8" && "$(uname)" = "Darwin" ]]; then
    # Manually override the tag in this case - CI will naively generate
-   # "macos_10_9_arm64" but this isn't a 'real' tag because the first
+   # "macosx_10_9_arm64" but this isn't a 'real' tag because the first
    # version of macOS supporting AArch64 was macOS 11 Big Sur